import java.io.BufferedReader;
import java.io.FileReader;
import java.io.FileWriter;
import java.io.IOException;
import java.io.PrintWriter;
import java.util.ArrayList;
import java.util.Locale;
import java.util.StringTokenizer;
import java.util.TreeSet;

public class cheese_sm_double {
    final double EPS = 1e-6;
    final boolean DEBUG = false;

    class Job {
        long p, r, d;

        public Job(long p, long r, long d) {
            assert 1 <= p && p <= 1e5;
            assert 0 <= r && r < d && d <= 1e7;
            this.p = p;
            this.r = r;
            this.d = d;
        }

        @Override
        public String toString() {
            return "< p = " + p + ",  r = " + r + " d = " + d + ">";
        }

    }

    class Edge {
        Vertex to;
        double cap;
        double flow;
        Edge reverse;

        public Edge(Vertex to, double cap) {
            this.to = to;
            this.cap = cap;
            this.flow = 0;
        }

        @Override
        public String toString() {
            return "(to = " + to + "[" + flow + "/" + cap + "])";
        }
    }

    class Vertex {
        ArrayList<Edge> e;
        boolean u;

        public Vertex() {
            allVertex.add(this);
            e = new ArrayList<Edge>();
        }
    }

    boolean equals(double a, double b) {
        return Math.abs(a - b) < EPS;
    }

    void addEdge(Vertex from, Vertex to, double cap) {
        Edge direct = new Edge(to, cap);
        Edge rev = new Edge(from, 0);
        direct.reverse = rev;
        rev.reverse = direct;
        from.e.add(direct);
        to.e.add(rev);
    }

    int n, m;
    Job[] jobs;
    long[] s;
    long S, P;
    ArrayList<Vertex> allVertex;
    Vertex source, sink;

    boolean can(double lat) {
        TreeSet<Double> t = new TreeSet<Double>();
        for (int i = 0; i < jobs.length; i++) {
            t.add((double) jobs[i].r);
            if (jobs[i].d + lat < jobs[i].r) {
                return false;
            }
            t.add(jobs[i].d + lat);
        }
        allVertex = new ArrayList<Vertex>();
        source = new Vertex();
        sink = new Vertex();
        Vertex[] J = new Vertex[n];
        for (int i = 0; i < J.length; i++) {
            J[i] = new Vertex();
            addEdge(source, J[i], jobs[i].p);
        }
        Double prev = null;
        for (Double d : t) {
            if (prev == null) {
                prev = d;
                continue;
            }
            if (equals(prev, d)) {
                continue;
            }
            if (DEBUG)
                System.err.println("Ik = [" + prev + ", " + d + "]");
            Vertex Ik = new Vertex();
            double Tk = d - prev;
            addEdge(Ik, sink, S * (Tk));

            Vertex[] K = new Vertex[m];
            for (int j = 0; j < K.length; j++) {
                K[j] = new Vertex();
                addEdge(K[j], Ik, (j + 1) * (s[j] - s[j + 1]) * Tk);
            }
            for (int i = 0; i < J.length; i++) {
                for (int j = 0; j < K.length; j++) {
                    if (jobs[i].r <= prev + EPS && d - EPS <= jobs[i].d + lat) {
                        if (DEBUG)
                            System.err.println(" can " + jobs[i].toString()
                                    + " with lat = " + lat);
                        addEdge(J[i], K[j], (s[j] - s[j + 1]) * (Tk));
                    }
                }
            }
            prev = d;
        }

        double flow = 0;

        double max = P;
        while (max > 2 * EPS) {
            max /= 2;
            while (true) {
                for (Vertex v : allVertex) {
                    v.u = false;
                }
                double d = dfs(source, Long.MAX_VALUE, max);
                if (d < max - EPS) {
                    break;
                }
                flow += d;

            }
        }
        if (DEBUG)
            System.err.println("flow = " + flow);
        if (DEBUG)
            System.err.println();

        if (equals(flow, P)) {
            return true;
        } else {
            return false;
        }
    }

    double dfs(Vertex v, double flowFromSource, double minEdge) {
        if (v == sink) {
            return flowFromSource;
        }
        v.u = true;
        for (Edge e : v.e) {
            if (e.cap - e.flow > minEdge && !e.to.u) {
                double q = dfs(e.to, Math.min(flowFromSource, e.cap - e.flow),
                        minEdge);
                if (q > minEdge - EPS) {
                    e.flow += q;
                    e.reverse.flow -= q;
                    return q;
                }
            }
        }
        return 0;
    }

    void solve() {
        n = nextInt();
        assert 1 <= n && n <= 30;
        m = nextInt();
        assert 1 <= m && m <= 30;
        jobs = new Job[n];
        P = 0;
        for (int i = 0; i < jobs.length; i++) {
            jobs[i] = new Job(nextInt(), nextInt(), nextInt());
            P += jobs[i].p;
        }
        s = new long[m + 1];
        // Add one fictive machine with s[m] = 0
        S = 0;
        for (int i = 0; i < m; i++) {
            s[i] = nextInt();
            S += s[i];
            assert 1 <= s[i] && s[i] <= 1e5;
        }
        for (int i = 0; i < s.length; i++) {
            for (int j = i + 1; j < s.length; j++) {
                if (s[i] < s[j]) {
                    long tmp = s[i];
                    s[i] = s[j];
                    s[j] = tmp;
                }
            }
        }
        // can(1000);
        // if (true)
        // return;
        double min = Long.MIN_VALUE;
        double max = Long.MAX_VALUE;
        for (int i = 0; i < 200; i++) {
            if (DEBUG)
                System.err.println(min + " " + max);
            double lat = (min + max) / 2;
            if (can(lat)) {
                max = lat;
            } else {
                min = lat;
            }
        }
        out.printf(Locale.US, "%.10f", Math.max(min, 0));
    }

    BufferedReader br;
    PrintWriter out;
    StringTokenizer st;

    void run() {
        try {
            br = new BufferedReader(new FileReader("cheese.in"));
            out = new PrintWriter(new FileWriter("cheese.out"));
            solve();
            out.close();
        } catch (IOException e) {
            e.printStackTrace();
            System.exit(1);
        }
    }

    String nextToken() {
        try {
            while (st == null || !st.hasMoreTokens()) {
                st = new StringTokenizer(br.readLine());
            }
            return st.nextToken();
        } catch (Exception e) {
            return "0";
        }
    }

    int nextInt() {
        return Integer.parseInt(nextToken());
    }

    public static void main(String[] args) {
        new cheese_sm_double().run();
    }
}
